/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2013-2023 Chaosdorf e.V.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package de.chaosdorf.meteroid.routes.main

import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.padding
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.automirrored.filled.ArrowBack
import androidx.compose.material3.Icon
import androidx.compose.material3.LinearProgressIndicator
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.material3.TopAppBar
import androidx.compose.runtime.Composable
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.ui.Modifier
import de.chaosdorf.meteroid.RepositorySyncHandler
import de.chaosdorf.meteroid.SyncHandler
import de.chaosdorf.meteroid.di.MainLayoutViewModel

@Composable
fun MainLayoutRoute(viewModel: MainLayoutViewModel) {
  val syncState by viewModel.syncState.collectAsState()

  Scaffold(
    topBar = {
      TopAppBar(
        title = {
          Text("Meteroid")
        },
        navigationIcon = {
          Icon(
            Icons.AutoMirrored.Default.ArrowBack,
            modifier = Modifier.clickable {
              viewModel.openServerSelection()
            },
            contentDescription = "Back"
          )
        }
      )
    }
  ) { paddingValues ->
    Column(Modifier.padding(paddingValues)) {
      if (syncState == SyncHandler.State.Syncing) {
        LinearProgressIndicator()
      }
      DrinkList(viewModel.drinkListViewModel)
    }
  }
}
