/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2013-2023 Chaosdorf e.V.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package de.chaosdorf.meteroid.routes.setup

import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.Add
import androidx.compose.material.icons.filled.Delete
import androidx.compose.material3.FloatingActionButton
import androidx.compose.material3.Icon
import androidx.compose.material3.ListItem
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.material3.TopAppBar
import androidx.compose.runtime.Composable
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.ui.Modifier
import coil.compose.AsyncImage
import de.chaosdorf.meteroid.di.ServerSelectionViewModel

@Composable
fun ServerSelectionRoute(viewModel: ServerSelectionViewModel) {
  val servers by viewModel.servers.collectAsState()

  Scaffold(
    topBar = {
      TopAppBar(
        title = { Text("Select Server") },
      )
    },
    floatingActionButton = {
      FloatingActionButton(
        onClick = { viewModel.addServer() }
      ) {
        Icon(
          Icons.Default.Add,
          contentDescription = "Select Server"
        )
      }
    }
  ) { paddingValues ->
    LazyColumn(modifier = Modifier.padding(paddingValues)) {
      items(servers) { server ->
        ListItem(
          modifier = Modifier.clickable {
            viewModel.select(server.id)
          },
          headlineContent = { Text(server.name ?: server.url) },
          leadingContent = {
            AsyncImage(model = server.logoUrl, contentDescription = null)
          },
          trailingContent = {
            Icon(
              Icons.Default.Delete,
              modifier = Modifier.clickable {
                viewModel.remove(server.id)
              },
              contentDescription = "Delete"
            )
          }
        )
      }
    }
  }
}
